@@ -1300,12 +1300,18 @@ class Enum(Field, metaclass=_EnumMeta):
         if self._is_enum:
             enum_names = {v.name for v in self._enum_class}
             if value not in enum_names and not isinstance(value, (self._enum_class,)):
+                enum_values = [r.name for r in self._enum_class]
+                if len(enum_values) < 11:
+                    raise ValueError(
+                        "{}: Got {}; Expected one of: {}".format(self._name, value, ", ".join(enum_values))
+                    )
                 raise ValueError(
-                    "{}: Must be a value of {}".format(self._name, self._enum_class)
+                    "{}: Got {}; Expected a value of {}".format(self._name, value, self._enum_class)
                 )
 
         elif value not in self.values:
-            raise ValueError("{}: Must be one of {}".format(self._name, self.values))
+            raise ValueError("{}: Got {}; Expected one of {}".format(
+                self._name, value, ', '.join([str(v) for v in self.values])))
 
     def __set__(self, instance, value):
         self._validate(value)
@@ -1351,7 +1357,7 @@ class Sized(Field):
 
     def __set__(self, instance, value):
         if len(value) > self.maxlen:
-            raise ValueError("{}: Too long".format(self._name))
+            raise ValueError("{}: Got {}; Expected a length up to {}".format(self._name, value, self.maxlen))
         super().__set__(instance, value)
 
 
