@@ -11,7 +11,7 @@ from typedpy.structures import (
     _get_all_fields_by_name,
     ADDITIONAL_PROPERTIES,
     REQUIRED_FIELDS,
-    IGNORE_NONE_VALUES,
+    IGNORE_NONE_VALUES, NoneField,
 )
 from typedpy.fields import (
     Field,
@@ -50,7 +50,7 @@ def deserialize_list_like(
     camel_case_convert=False,
 ):
     if not isinstance(value, (list, tuple, set)):
-        raise ValueError("{}: must be list, set, or tuple; got {}".format(name, value))
+        raise ValueError("{}: Got {}; Expected a list, set, or tuple".format(name, value))
 
     values = []
     items = field.items
@@ -167,6 +167,8 @@ def deserialize_multifield_wrapper(
     """
     deserialized = source_val
     found_previous_match = False
+    failures = 0
+    err_messages = []
     for field_option in field.get_fields():
         try:
             ignore_none = getattr(field_option, IGNORE_NONE_VALUES, False)
@@ -184,31 +186,42 @@ def deserialize_multifield_wrapper(
                 return deserialized
             elif isinstance(field, NotField):
                 raise ValueError(
-                    "could not deserialize {}: value {} matches field {}, but must not match it".format(
+                    "{}: Got {}; Matches field {}, but must not match it".format(
                         name, wrap_val(source_val), field
                     )
                 )
             elif isinstance(field, OneOf) and found_previous_match:
                 raise ValueError(
-                    "could not deserialize {}: value {} matches more than one match".format(
+                    "{}: Got {}; Matches more than one match".format(
                         name, wrap_val(source_val)
                     )
                 )
             found_previous_match = True
         except Exception as e:
+            failures += 1
+            err_messages.append("({}) Does not match {}. reason: {}".format(
+                len(err_messages) + 1,
+                field_option, str(e)))
             if isinstance(field, AllOf):
                 raise ValueError(
-                    "could not deserialize {}: value {} did not match {}. reason: {}".format(
+                    "{}: Got {}; Does not match {}. reason: {}".format(
                         name, wrap_val(source_val), field_option, str(e)
                     )
                 ) from e
+    if failures == len(field.get_fields()) and not isinstance(field, NotField):
+        raise ValueError(
+            "{}: Got {}; Does not match any field option: {}".format(
+                name, wrap_val(source_val),
+                ". ".join(err_messages)
+            )
+        )
     return deserialized
 
 
 def deserialize_map(map_field, source_val, name, camel_case_convert=False):
     if not isinstance(source_val, dict):
         raise TypeError(
-            "{}: expected a dict. Got {}".format(name, wrap_val(source_val))
+            "{}: Got {}; Expected a dictionary".format(name, wrap_val(source_val))
         )
     if map_field.items:
         key_field, value_field = map_field.items
@@ -242,7 +255,7 @@ def deserialize_single_field(
     camel_case_convert=False,
     ignore_none=False,
 ):
-    if source_val is None and ignore_none:
+    if source_val is None and (ignore_none or isinstance(field, NoneField)):
         return source_val
     if isinstance(field, (Number, String, Enum, Boolean)):
         field._validate(source_val)
@@ -308,13 +321,16 @@ def deserialize_single_field(
             camel_case_convert=camel_case_convert,
         )
     elif isinstance(field, StructureReference):
-        value = deserialize_structure_reference(
-            getattr(field, "_newclass"),
-            source_val,
-            keep_undefined=keep_undefined,
-            mapper=mapper,
-            camel_case_convert=camel_case_convert,
-        )
+        try:
+            value = deserialize_structure_reference(
+                getattr(field, "_newclass"),
+                source_val,
+                keep_undefined=keep_undefined,
+                mapper=mapper,
+                camel_case_convert=camel_case_convert,
+            )
+        except Exception as e:
+            raise ValueError("{}: Got {}; {}".format(name,  wrap_val(source_val), str(e))) from e
     elif isinstance(field, Map):
         value = deserialize_map(
             field, source_val, name, camel_case_convert=camel_case_convert
@@ -329,10 +345,12 @@ def deserialize_single_field(
             value = ty(*source_val)
         elif isinstance(source_val, dict):
             value = ty(**source_val)
+    elif isinstance(field, NoneField):
+        raise ValueError("{}: Got {}; Expected None".format(name,  wrap_val(source_val)))
     else:
         raise NotImplementedError(
-            "cannot deserialize field '{}' of type {} using value {}. Are you using non-Typepy class?".format(
-                name, field.__class__.__name__, wrap_val(source_val)
+            "{}: Got {}; Cannot deserialize value of type {}. Are you using non-Typepy class?".format(
+                name, wrap_val(source_val), field.__class__.__name__
             )
         )
     return value
@@ -372,6 +390,7 @@ def construct_fields_map(
     ignore_none=False,
 ):
     result = {}
+    errors = []
     for key, field in field_by_name.items():
         converted_key = _convert_to_camel_case_if_required(
             key, camel_case_convert=camel_case_convert
@@ -389,15 +408,33 @@ def construct_fields_map(
             process = True
         if process:
             sub_mapper = mapper.get(f"{converted_key}._mapper", {})
-            result[key] = deserialize_single_field(
-                field,
-                processed_input,
-                key,
-                mapper=sub_mapper,
-                keep_undefined=keep_undefined,
-                camel_case_convert=camel_case_convert,
-                ignore_none=ignore_none,
-            )
+            if Structure.failing_fast():
+                result[key] = deserialize_single_field(
+                    field,
+                    processed_input,
+                    key,
+                    mapper=sub_mapper,
+                    keep_undefined=keep_undefined,
+                    camel_case_convert=camel_case_convert,
+                    ignore_none=ignore_none,
+                )
+            else:
+                try:
+                    result[key] = deserialize_single_field(
+                        field,
+                        processed_input,
+                        key,
+                        mapper=sub_mapper,
+                        keep_undefined=keep_undefined,
+                        camel_case_convert=camel_case_convert,
+                        ignore_none=ignore_none,
+                    )
+                except (TypeError, ValueError) as ex:
+                    errors.append(ex)
+    if errors:
+        messages = json.dumps([str(e) for e in errors])
+        raise errors[0].__class__(messages) from errors[0]
+
     return result
 
 
@@ -598,10 +635,12 @@ def serialize_val(field_definition, name, val, mapper=None, camel_case_convert=F
                     )
                     for (k, v) in val.items()
                 }
-        if isinstance(field_definition.items, list):
+
+        items = getattr(field_definition, "items", None)
+        if isinstance(items, list):
             return [
                 serialize_val(
-                    field_definition.items[ind],
+                    items[ind],
                     name,
                     v,
                     mapper=mapper,
@@ -609,10 +648,10 @@ def serialize_val(field_definition, name, val, mapper=None, camel_case_convert=F
                 )
                 for ind, v in enumerate(val)
             ]
-        elif isinstance(field_definition.items, Field):
+        elif isinstance(items, Field):
             return [
                 serialize_val(
-                    field_definition.items,
+                    items,
                     name,
                     i,
                     mapper=mapper,
